pub struct PeerInfo {
pub id: u32,
pub address: SocketAddr,
pub services: ServiceFlags,
pub user_agent: String,
pub initial_height: u32,
pub state: PeerStatus,
pub kind: ConnectionKind,
pub transport_protocol: TransportProtocol,
}Expand description
A struct representing a peer connected to the node.
This struct contains information about a peer connected to the node, like its address, the services it provides, the user agent it’s using, the height of the blockchain it’s currently at, its state and the kind of connection it has with the node.
Fields
id: u32address: SocketAddrservices: ServiceFlagsuser_agent: Stringinitial_height: u32state: PeerStatuskind: ConnectionKindtransport_protocol: TransportProtocolTrait Implementations